@@ -583,6 +583,46 @@ struct security_hook_heads * __init probe_security_hook_heads(void)
 	return NULL;
 }
 
+#elif defined(RHEL_MAJOR) && RHEL_MAJOR == 8 && defined(RHEL_MINOR) && RHEL_MINOR >= 6
+
+/**
+ * probe_security_hook_heads - Find address of "struct security_hook_heads security_hook_heads".
+ *
+ * Returns pointer to "struct security_hook_heads" on success, NULL otherwise.
+ */
+struct security_hook_heads * __init probe_security_hook_heads(void)
+{
+	const unsigned int offset = offsetof(struct security_hook_heads,
+					     bprm_committed_creds);
+	void *cp;
+	struct security_hook_heads *shh;
+	struct security_hook_list *entry;
+	void *cap = probe_find_symbol(" cap_bprm_repopulate_creds\n");
+
+	/* Get location of cap_bprm_repopulate_creds(). */
+	cap = check_function_address(cap, "cap_bprm_repopulate_creds");
+	if (!cap)
+		return NULL;
+	/* Guess "struct security_hook_heads security_hook_heads;". */
+	cp = probe_find_variable(probe_security_bprm_committed_creds,
+				 ((unsigned long)
+				  &probe_dummy_security_hook_heads) + offset,
+				 " security_bprm_committed_creds\n");
+	if (!cp) {
+		printk(KERN_ERR
+		       "Can't resolve security_bprm_committed_creds().\n");
+		return NULL;
+	}
+	/* This should be "struct security_hook_heads security_hook_heads;". */
+	shh = ((void *) (*(unsigned long *) cp)) - offset;
+	hlist_for_each_entry(entry, &shh->bprm_repopulate_creds, list)
+		if (entry->hook.bprm_repopulate_creds == cap)
+			return shh;
+	printk(KERN_ERR "Guessed security_hook_heads is 0x%lx\n",
+	       (unsigned long) shh);
+	return NULL;
+}
+
 #elif defined(LSM_HOOK_INIT)
 
 /**
@@ -956,3 +996,19 @@ void * __init probe_d_absolute_path(void)
 }
 
 #endif
+
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(5, 8, 0)
+
+/**
+ * probe_copy_to_kernel_nofault - Find address of "copy_to_kernel_nofault()".
+ *
+ * Returns address of copy_to_kernel_nofault() on success, NULL otherwise.
+ */
+void * __init probe_copy_to_kernel_nofault(void)
+{
+	void *ptr = probe_find_symbol(" copy_to_kernel_nofault\n");
+
+	return check_function_address(ptr, "copy_to_kernel_nofault");
+}
+
+#endif
